summaryrefslogtreecommitdiff
path: root/shmem/win32
diff options
context:
space:
mode:
authorJeff Trawick <trawick@apache.org>2014-01-18 13:40:24 +0000
committerJeff Trawick <trawick@apache.org>2014-01-18 13:40:24 +0000
commit885e5359bf60d7bdc061d94d817e73f2df0014fb (patch)
tree0f1da1740b5ddc2dd45536977f957f7582c6faf3 /shmem/win32
parent12799133a8830f567ef7d0a45c0b61806eae1ea8 (diff)
downloadapr-885e5359bf60d7bdc061d94d817e73f2df0014fb.tar.gz
stop using deprecated versions of APR_FOPEN_* and APR_FPROT_*
git-svn-id: https://svn.apache.org/repos/asf/apr/apr/trunk@1559343 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'shmem/win32')
-rw-r--r--shmem/win32/shm.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/shmem/win32/shm.c b/shmem/win32/shm.c
index af0115e44..28ce9406b 100644
--- a/shmem/win32/shm.c
+++ b/shmem/win32/shm.c
@@ -158,13 +158,13 @@ APR_DECLARE(apr_status_t) apr_shm_create_ex(apr_shm_t **m,
int global;
/* Do file backed, which is not an inherited handle
* While we could open APR_EXCL, it doesn't seem that Unix
* ever did. Ignore that error here, but fail later when
* we discover we aren't the creator of the file map object.
*/
rv = apr_file_open(&f, file,
- APR_READ | APR_WRITE | APR_BINARY | APR_CREATE,
- APR_UREAD | APR_UWRITE, pool);
+ APR_FOPEN_READ | APR_FOPEN_WRITE | APR_FOPEN_BINARY | APR_FOPEN_CREATE,
+ APR_FPROT_UREAD | APR_FPROT_UWRITE, pool);
if ((rv != APR_SUCCESS)
|| ((rv = apr_os_file_get(&hFile, f)) != APR_SUCCESS)) {
return rv;
@@ -158,13 +158,13 @@ APR_DECLARE(apr_status_t) apr_shm_create_ex(apr_shm_t **m,
int global;
/* Do file backed, which is not an inherited handle
- * While we could open APR_EXCL, it doesn't seem that Unix
+ * While we could open APR_FOPEN_EXCL, it doesn't seem that Unix
* ever did. Ignore that error here, but fail later when
* we discover we aren't the creator of the file map object.